@@ -3,6 +3,7 @@ from io import BytesIO
 from scipy.io import wavfile
 from urllib.parse import urlparse
 import subprocess
+from aws_sagemaker_remote.inference.mime import FIX_FORMATS
 
 
 def transcode_ffmpeg(data, input_fmt='wav', sample_rate=None, channels=1, codec='pcm_s16le'):
@@ -12,6 +13,8 @@ def transcode_ffmpeg(data, input_fmt='wav', sample_rate=None, channels=1, codec=
     Use pipes and run in-memory
     """
     assert input_fmt, "input_fmt is required in transcode_ffmpeg"
+    if input_fmt.lower() in FIX_FORMATS:
+        input_fmt = FIX_FORMATS[input_fmt.lower()]
     #print(f"transcode_ffmpeg input_fmt: {input_fmt}")
     cmd = [
         'ffmpeg',
@@ -30,7 +33,7 @@ def transcode_ffmpeg(data, input_fmt='wav', sample_rate=None, channels=1, codec=
     ])
     proc = subprocess.run(
         cmd,
-        #capture_output=True,
+        # capture_output=True,
         input=data,
         check=True,
         stdout=subprocess.PIPE
